FileWriteSession class

Constructors

FileWriteSession({required Future<void> onAdd(Uint8List chunk), required Future<PickedEntry> onClose(), required Future<void> onCancel(), int? totalBytes, FilegateWriteProgressCallback? onProgress})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(List<int> chunk) Future<void>
addStream(Stream<List<int>> chunks) Future<void>
cancel() Future<void>
close() Future<PickedEntry>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited