FilegateCapabilities class
Constructors
- FilegateCapabilities({required bool supportsFilePicking, required bool supportsDirectoryPicking, required bool supportsMixedPicking, required bool supportsInitialDirectory, required bool supportsPersistedAccess, required bool supportsNativeUriRead, bool supportsFileSaving = false, bool supportsFileWriting = false, bool supportsFileStreamWriting = false})
-
const
-
FilegateCapabilities.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsDirectoryPicking → bool
-
final
- supportsFilePicking → bool
-
final
- supportsFileSaving → bool
-
final
- supportsFileStreamWriting → bool
-
final
- supportsFileWriting → bool
-
final
- supportsInitialDirectory → bool
-
final
- supportsMixedPicking → bool
-
final
- supportsNativeUriRead → bool
-
final
- supportsPersistedAccess → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited