FilegateSaveOptions class

Constructors

FilegateSaveOptions({required Uint8List bytes, required String suggestedName, List<String> allowedExtensions = const [], String? title, String? initialDirectory, String? mimeType, bool persistAccess = true})
const

Properties

allowedExtensions List<String>
final
bytes Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
initialDirectory String?
final
mimeType String?
final
persistAccess bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggestedName String
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited