PickedEntry class

Constructors

PickedEntry({required String path, required String name, required PickedEntryKind kind, String? relativePath, PickedEntryMetadata metadata = PickedEntryMetadata.empty})
const
PickedEntry.fromMap(Map<Object?, Object?> map)
factory

Properties

fileSystemPath String?
no setter
hashCode int
The hash code for this object.
no setterinherited
isContentUri bool
no setter
isDirectory bool
no setter
isFile bool
no setter
isUri bool
no setter
kind PickedEntryKind
final
locationKind FilegateLocationKind
no setter
metadata PickedEntryMetadata
final
mimeType String?
no setter
modifiedAt DateTime?
no setter
name String
final
path String
final
relativePath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
no setter
uri Uri?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited