PickedEntryMetadata class

Constructors

PickedEntryMetadata({int? size, DateTime? modifiedAt, String? mimeType})
const
PickedEntryMetadata.fromMap(Map<Object?, Object?> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
isNotEmpty bool
no setter
mimeType String?
final
modifiedAt DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

empty → const PickedEntryMetadata