MethodChannelFilegate class
An implementation of FilegatePlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FilegatePlatform
- MethodChannelFilegate
Constructors
- MethodChannelFilegate({@visibleForTesting bool forceNativeRead = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCapabilities(
) → Future< FilegateCapabilities> -
override
-
getFileSize(
String path) → Future< int?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openRead(
String path, {int chunkSize = 64 * 1024, int start = 0, int? end}) → FileReadSession< Uint8List> -
override
-
openWrite(
String path, {FilegateWriteMode mode = FilegateWriteMode.replace}) → Future< FileWriteSession> -
override
-
pick(
FilegatePickOptions options) → Future< List< PickedEntry> ?> -
override
-
save(
FilegateSaveOptions options) → Future< PickedEntry?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
FilegateWriteOptions options) → Future< PickedEntry> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
capabilitiesForOperatingSystem(
String operatingSystem) → FilegateCapabilities