FilegatePlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- FilegatePlatform
- Implementers
Constructors
- FilegatePlatform()
- Constructs a FilegatePlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCapabilities(
) → Future< FilegateCapabilities> -
getFileSize(
String path) → Future< int?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openRead(
String path, {int chunkSize = 64 * 1024, int start = 0, int? end}) → FileReadSession< Uint8List> -
openWrite(
String path, {FilegateWriteMode mode = FilegateWriteMode.replace}) → Future< FileWriteSession> -
pick(
FilegatePickOptions options) → Future< List< PickedEntry> ?> -
save(
FilegateSaveOptions options) → Future< PickedEntry?> -
toString(
) → String -
A string representation of this object.
inherited
-
write(
FilegateWriteOptions options) → Future< PickedEntry>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FilegatePlatform
-
The default instance of FilegatePlatform to use.
getter/setter pair