FilegatePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FilegatePlatform
Implementers

Constructors

FilegatePlatform()
Constructs a FilegatePlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFileSize(String path) Future<int?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openRead(String path, {int chunkSize = 64 * 1024, int start = 0}) FileReadSession<Uint8List>
pick(FilegatePickOptions options) Future<List<PickedEntry>?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FilegatePlatform
The default instance of FilegatePlatform to use.
getter/setter pair